/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                  GRADO TERMINAL DE BACHILLERATO (Excale 12)
/*
/*                        **** FORMACIN CIUDADANA ****
/*
/*                     Ciclo escolar evaluado: 2009 - 2010
/*_____________________________________________________________________________
/*
/*
/*  PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE FORMACIN CIUDADANA
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale12_2010_Alum_FC.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale12_2010_Alum_FC.txt
/*         as como el archivo Excale12_2010_Alum_FC.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale12_2010_Alum_FC.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale12_2010_Alum_FC.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 23 DE NOVIEMBRE DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale12_2010_Alum_FC.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     10        = "Bachillerato General"
                       11        = "Bachillerato Tecnolgico"
                       12        = "Profesional Tcnico";
     VALUE $modF       "BG"      = "Bachillerato General"
                       "BT"      = "Bachillerato Tecnolgico"
                       "PT"      = "Profesional Tcnico";
     VALUE ESTRATOF    111       = "BG_Autnomo<34"
                       112       = "BG_Autnomo_34-100"
                       113       = "BG_Autnomo_101-500"
                       114       = "BG_Autnomo>500"
                       121       = "BG_COBACH<34"
                       122       = "BG_COBACH_34-100"
                       123       = "BG_COBACH_101-500"
                       124       = "BG_COBACH>500"
                       131       = "BG_otros<34"
                       132       = "BG_otros_34-100"
                       133       = "BG_otros_101-500"
                       134       = "BG_otros>500"
                       141       = "BG_privadas<34"
                       142       = "BG_privadas_34-100"
                       143       = "BG_privadas_101-500"
                       144       = "BG_privadas>500"
                       211       = "BT_CBTIS<34"
                       212       = "BT_CBTIS_34-100"
                       213       = "BT_CBTIS_101-500"
                       214       = "BT_CBTIS>500"
                       221       = "BT_otros<34"
                       222       = "BT_otros_34-100"
                       223       = "BT_otros_101-500"
                       224       = "BT_otros>500"
                       311       = "PT_CONALEP<34"
                       312       = "PT_CONALEP_34-100"
                       313       = "PT_CONALEP_101-500"
                       314       = "PT_CONALEP>500"
                       321       = "PT_otros<34"
                       322       = "PT_otros_34-100"
                       323       = "PT_otros_101-500"
                       324       = "PT_otros>500";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edad_acF    8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE BC1_52F     0         = "Incorrecto"
                       1         = "Correcto"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
RUN;



DATA INEE.Excale12_2010_Alum_FC;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            3
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD_AC            3
       W_ALU              8
       BC__01             3
       BC__02             3
       BC__03             3
       BC__06             3
       BC__04             3
       BC__05             3
       BC__08             3
       BC__07             3
       BC__09             3
       BC__11             3
       BC__10             3
       BC__12             3
       BC__14             3
       BC__15             3
       BC__13             3
       BC__17             3
       BC__16             3
       BC__18             3
       BC__19             3
       BC__20             3
       BC__21             3
       BC__23             3
       BC__22             3
       BC__24             3
       BC__26             3
       BC__25             3
       BC__27             3
       BC__31             3
       BC__28             3
       BC__29             3
       BC__30             3
       BC__32             3
       BC__33             3
       BC__35             3
       BC__34             3
       BC__36             3
       BC__37             3
       BC__39             3
       BC__38             3
       BC__40             3
       BC__41             3
       BC__43             3
       BC__42             3
       BC__44             3
       BC__45             3
       BC__46             3
       BC__47             3
       BC__48             3
       BC__49             3
       BC__50             3
       BC__51             3
       BC__52             3
       PV1FC              8
       PV2FC              8
       PV3FC              8
       PV4FC              8
       PV5FC              8
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
       W_FSTR81           8
       W_FSTR82           8
       W_FSTR83           8
       W_FSTR84           8
       W_FSTR85           8
       W_FSTR86           8
       W_FSTR87           8
       W_FSTR88           8
       W_FSTR89           8
       W_FSTR90           8
       W_FSTR91           8
       W_FSTR92           8
       W_FSTR93           8
       W_FSTR94           8
       W_FSTR95           8
       W_FSTR96           8
       W_FSTR97           8
       W_FSTR98           8
       W_FSTR99           8
       W_FSTR100          8
       W_FSTR101          8
       W_FSTR102          8
       W_FSTR103          8
       W_FSTR104          8
       W_FSTR105          8
       W_FSTR106          8
       W_FSTR107          8
       W_FSTR108          8
       W_FSTR109          8
       W_FSTR110          8
       W_FSTR111          8
       W_FSTR112          8
       W_FSTR113          8
       W_FSTR114          8
       W_FSTR115          8
       W_FSTR116          8
       W_FSTR117          8
       W_FSTR118          8
       W_FSTR119          8
       W_FSTR120          8
       W_FSTR121          8
       W_FSTR122          8
       W_FSTR123          8
       W_FSTR124          8
       W_FSTR125          8
       W_FSTR126          8
       W_FSTR127          8
       W_FSTR128          8
 ;

INFILE alum MISSOVER LINESIZE = 1577;
   INPUT
        Nacional             1 - 1
        escuela              2 - 5
        id_ent               6 - 7
        nom_ent              8 - 26
        id_mod              27 - 28
        mod                 29 - 32
        Estrato             33 - 39
        alumno              40 - 45
        id_instr            46 - 61
        sexo                62 - 62
        edad_ac             63 - 63
        w_alu               64 - 74
        bc__01              75 - 75
        bc__02              76 - 76
        bc__03              77 - 77
        bc__06              78 - 78
        bc__04              79 - 79
        bc__05              80 - 80
        bc__08              81 - 81
        bc__07              82 - 82
        bc__09              83 - 83
        bc__11              84 - 84
        bc__10              85 - 85
        bc__12              86 - 86
        bc__14              87 - 87
        bc__15              88 - 88
        bc__13              89 - 89
        bc__17              90 - 90
        bc__16              91 - 91
        bc__18              92 - 92
        bc__19              93 - 93
        bc__20              94 - 94
        bc__21              95 - 95
        bc__23              96 - 96
        bc__22              97 - 97
        bc__24              98 - 98
        bc__26              99 - 99
        bc__25             100 - 100
        bc__27             101 - 101
        bc__31             102 - 102
        bc__28             103 - 103
        bc__29             104 - 104
        bc__30             105 - 105
        bc__32             106 - 106
        bc__33             107 - 107
        bc__35             108 - 108
        bc__34             109 - 109
        bc__36             110 - 110
        bc__37             111 - 111
        bc__39             112 - 112
        bc__38             113 - 113
        bc__40             114 - 114
        bc__41             115 - 115
        bc__43             116 - 116
        bc__42             117 - 117
        bc__44             118 - 118
        bc__45             119 - 119
        bc__46             120 - 120
        bc__47             121 - 121
        bc__48             122 - 122
        bc__49             123 - 123
        bc__50             124 - 124
        bc__51             125 - 125
        bc__52             126 - 126
        pv1FC              127 - 134
        pv2FC              135 - 142
        pv3FC              143 - 150
        pv4FC              151 - 158
        pv5FC              159 - 166
        wvarstrr           167 - 169
        W_FSTR1            170 - 180
        W_FSTR2            181 - 191
        W_FSTR3            192 - 202
        W_FSTR4            203 - 213
        W_FSTR5            214 - 224
        W_FSTR6            225 - 235
        W_FSTR7            236 - 246
        W_FSTR8            247 - 257
        W_FSTR9            258 - 268
        W_FSTR10           269 - 279
        W_FSTR11           280 - 290
        W_FSTR12           291 - 301
        W_FSTR13           302 - 312
        W_FSTR14           313 - 323
        W_FSTR15           324 - 334
        W_FSTR16           335 - 345
        W_FSTR17           346 - 356
        W_FSTR18           357 - 367
        W_FSTR19           368 - 378
        W_FSTR20           379 - 389
        W_FSTR21           390 - 400
        W_FSTR22           401 - 411
        W_FSTR23           412 - 422
        W_FSTR24           423 - 433
        W_FSTR25           434 - 444
        W_FSTR26           445 - 455
        W_FSTR27           456 - 466
        W_FSTR28           467 - 477
        W_FSTR29           478 - 488
        W_FSTR30           489 - 499
        W_FSTR31           500 - 510
        W_FSTR32           511 - 521
        W_FSTR33           522 - 532
        W_FSTR34           533 - 543
        W_FSTR35           544 - 554
        W_FSTR36           555 - 565
        W_FSTR37           566 - 576
        W_FSTR38           577 - 587
        W_FSTR39           588 - 598
        W_FSTR40           599 - 609
        W_FSTR41           610 - 620
        W_FSTR42           621 - 631
        W_FSTR43           632 - 642
        W_FSTR44           643 - 653
        W_FSTR45           654 - 664
        W_FSTR46           665 - 675
        W_FSTR47           676 - 686
        W_FSTR48           687 - 697
        W_FSTR49           698 - 708
        W_FSTR50           709 - 719
        W_FSTR51           720 - 730
        W_FSTR52           731 - 741
        W_FSTR53           742 - 752
        W_FSTR54           753 - 763
        W_FSTR55           764 - 774
        W_FSTR56           775 - 785
        W_FSTR57           786 - 796
        W_FSTR58           797 - 807
        W_FSTR59           808 - 818
        W_FSTR60           819 - 829
        W_FSTR61           830 - 840
        W_FSTR62           841 - 851
        W_FSTR63           852 - 862
        W_FSTR64           863 - 873
        W_FSTR65           874 - 884
        W_FSTR66           885 - 895
        W_FSTR67           896 - 906
        W_FSTR68           907 - 917
        W_FSTR69           918 - 928
        W_FSTR70           929 - 939
        W_FSTR71           940 - 950
        W_FSTR72           951 - 961
        W_FSTR73           962 - 972
        W_FSTR74           973 - 983
        W_FSTR75           984 - 994
        W_FSTR76           995 - 1005
        W_FSTR77          1006 - 1016
        W_FSTR78          1017 - 1027
        W_FSTR79          1028 - 1038
        W_FSTR80          1039 - 1049
        W_FSTR81          1050 - 1060
        W_FSTR82          1061 - 1071
        W_FSTR83          1072 - 1082
        W_FSTR84          1083 - 1093
        W_FSTR85          1094 - 1104
        W_FSTR86          1105 - 1115
        W_FSTR87          1116 - 1126
        W_FSTR88          1127 - 1137
        W_FSTR89          1138 - 1148
        W_FSTR90          1149 - 1159
        W_FSTR91          1160 - 1170
        W_FSTR92          1171 - 1181
        W_FSTR93          1182 - 1192
        W_FSTR94          1193 - 1203
        W_FSTR95          1204 - 1214
        W_FSTR96          1215 - 1225
        W_FSTR97          1226 - 1236
        W_FSTR98          1237 - 1247
        W_FSTR99          1248 - 1258
        W_FSTR100         1259 - 1269
        W_FSTR101         1270 - 1280
        W_FSTR102         1281 - 1291
        W_FSTR103         1292 - 1302
        W_FSTR104         1303 - 1313
        W_FSTR105         1314 - 1324
        W_FSTR106         1325 - 1335
        W_FSTR107         1336 - 1346
        W_FSTR108         1347 - 1357
        W_FSTR109         1358 - 1368
        W_FSTR110         1369 - 1379
        W_FSTR111         1380 - 1390
        W_FSTR112         1391 - 1401
        W_FSTR113         1402 - 1412
        W_FSTR114         1413 - 1423
        W_FSTR115         1424 - 1434
        W_FSTR116         1435 - 1445
        W_FSTR117         1446 - 1456
        W_FSTR118         1457 - 1467
        W_FSTR119         1468 - 1478
        W_FSTR120         1479 - 1489
        W_FSTR121         1490 - 1500
        W_FSTR122         1501 - 1511
        W_FSTR123         1512 - 1522
        W_FSTR124         1523 - 1533
        W_FSTR125         1534 - 1544
        W_FSTR126         1545 - 1555
        W_FSTR127         1556 - 1566
        W_FSTR128         1567 - 1577
;

   LABEL
      NACIONAL     = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA      = "Identificador de la escuela"
      ID_ENT       = "Entidad federativa (identificador numrico)"
      NOM_ENT      = "Entidad federativa"
      ID_MOD       = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD          = "Estrato escolar o Modalidad educativa"
      ESTRATO      = "Estrato de muestreo"
      ALUMNO       = "Identificador del alumno"
      ID_INSTR     = "Identificador del cuadernillo de examen"
      SEXO         = "Sexo del alumno"
      EDAD_AC      = "Edad en aos cumplidos (al momento de la aplicacin)"
      W_ALU        = "Peso muestral o ponderador del alumno"
      BC__01       = "Reconocer algunas prcticas que favorecen la salud fsica"
      BC__02       = "Reconocer al dialogo como una prctica que favorece la salud mental"
      BC__03       = "Reconocer los alcances de sus potencialidades"
      BC__04       = "Reconocer estrategias para poner en prctica sus potencialidades"
      BC__05       = "Discriminar situaciones donde est en juego el respeto a s mismo"
      BC__06       = "Identificar el ejercicio responsable de la sexualidad como una accin orientada al cuidado de s"
      BC__07       = "Reconocer que la identidad se transforman a lo largo de la vida"
      BC__08       = "Reconocer que en la identidad inciden elementos sociales, culturales y polticos"
      BC__09       = "Identificar situaciones donde se manifiesta la discriminacin social"
      BC__10       = "Reconocer la libertad para asociarse como un derecho humano"
      BC__11       = "Identificar situaciones del mundo donde se trasgreden los derechos humanos"
      BC__12       = "Reconocer instancias internacionales que respaldan sus derechos"
      BC__13       = "Tomar una postura ante una problemtica que le afecta"
      BC__14       = "Identificar problemticas que afectan la vida social"
      BC__15       = "Identificar acciones que hacen referencia a un ejercicio responsable de la libertad"
      BC__16       = "Identificar una posicin autnoma e independiente para asumir una opinin"
      BC__17       = "Identificar a la familia tradicional como una construccin sociohistrica que puede cambiar"
      BC__18       = "Identificar elementos que dan cuenta del respeto y aprecio por los pueblos indgenas"
      BC__19       = "Identificar situaciones de la vida cotidiana donde se exprese el respeto a las diferencias"
      BC__20       = "Identificar situaciones donde se manifiesta el respeto a los derechos del otro"
      BC__21       = "Identificar al dilogo como elemento de la convivencia democrtica"
      BC__22       = "Reconocer una postura que denota respeto de los derechos humanos y rechazo a la discriminacin"
      BC__23       = "Reconocer acciones que muestran el aprecio a las tradiciones y costumbres de un grupo indgena"
      BC__24       = "Reconocer actitudes que propician el respeto a la diversidad y favorecen la convivencia"
      BC__25       = "Identificar situaciones donde se muestra mayor inters social sobre el personal"
      BC__26       = "Reconocer algunas actitudes que favorecen el dilogo e intercambio de ideas"
      BC__27       = "Reconocer que los argumentos son un elemento para trabajar en equipo y solucionar un conflicto"
      BC__28       = "Identificar situaciones de trabajo en equipo que contribuyen al logro de un objetivo comn"
      BC__29       = "Identificar elementos que favorecen la construccin de acuerdos orientados al bien comn"
      BC__30       = "Identificar actitudes que favorecen el trabajo en equipo"
      BC__31       = "Reconocer la responsabilidad de los involucrados en la solucin de un conflicto"
      BC__32       = "Reconocer actitudes de responsabilidad que le corresponden en las decisiones colectivas"
      BC__33       = "Identificar el compromiso como elemento para la resolucin de un conflicto"
      BC__34       = "Identificar algunos principios de la democracia"
      BC__35       = "Identificar relaciones entre los intereses personales y el inters general de la sociedad"
      BC__36       = "Reconocer posturas reflexivas frente a asuntos relacionados con el bien comn"
      BC__37       = "Reconocer que las manifestaciones sociales son una manera responsable de participar en asuntos pblicos"
      BC__38       = "Identificar elementos de la participacin social responsable en asuntos pblicos"
      BC__39       = "Identificar las expresiones juveniles como necesidades sociales"
      BC__40       = "Identificar algunos mecnismos que contribuyen a la solucin de necesidades sociales"
      BC__41       = "Reconocer situaciones donde se ponga de manifiesto la legalidad y la legitimidad"
      BC__42       = "Identificar situaciones donde se manifiesta el apego a la legalidad"
      BC__43       = "Identificar una parte de la organizacin poltica del Estado"
      BC__44       = "Identificar situaciones donde se violenta el orden constitucional"
      BC__45       = "Reconocer situaciones donde se manifiesta la soberana popular"
      BC__46       = "Reconocer que el conflicto es inherente a la condicin humana"
      BC__47       = "Identificar actitudes de empata para la solucin de conflictos"
      BC__48       = "Identificar un mecanismo democrtico para resolver un conflicto social"
      BC__49       = "Identificar situaciones donde el dilogo y el consenso permiten la resolucin de un conflicto"
      BC__50       = "Reconocer que el dilogo contribuye a satisfacer los intereses de las partes involucradas en un conflicto"
      BC__51       = "Identificar actitudes de respeto al dilogo para la solucin de un conflicto"
      BC__52       = "Identificar la negociacin como una herramienta en la solucin de un conflicto"
      PV1FC        = "Primer valor plausible de Formacin Ciudadana"
      PV2FC        = "Segundo valor plausible de Formacin Ciudadana"
      PV3FC        = "Tercer valor plausible de Formacin Ciudadana"
      PV4FC        = "Cuarto valor plausible de Formacin Ciudadana"
      PV5FC        = "Quinto valor plausible de Formacin Ciudadana"
      WVARSTRR     = "Identificador del pseudoestrato (1 a 128) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR101    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR102    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR103    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR104    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR105    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR106    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR107    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR108    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR109    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR110    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR111    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR112    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR113    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR114    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR115    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR116    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR117    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR118    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR119    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR120    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR121    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR122    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR123    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR124    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR125    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR126    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR127    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR128    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       estrato            EstratoF.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad_ac            edad_acF.
       BC__01             BC1_52F.
       BC__02             BC1_52F.
       BC__03             BC1_52F.
       BC__04             BC1_52F.
       BC__05             BC1_52F.
       BC__06             BC1_52F.
       BC__07             BC1_52F.
       BC__08             BC1_52F.
       BC__09             BC1_52F.
       BC__10             BC1_52F.
       BC__11             BC1_52F.
       BC__12             BC1_52F.
       BC__13             BC1_52F.
       BC__14             BC1_52F.
       BC__15             BC1_52F.
       BC__16             BC1_52F.
       BC__17             BC1_52F.
       BC__18             BC1_52F.
       BC__19             BC1_52F.
       BC__20             BC1_52F.
       BC__21             BC1_52F.
       BC__22             BC1_52F.
       BC__23             BC1_52F.
       BC__24             BC1_52F.
       BC__25             BC1_52F.
       BC__26             BC1_52F.
       BC__27             BC1_52F.
       BC__28             BC1_52F.
       BC__29             BC1_52F.
       BC__30             BC1_52F.
       BC__31             BC1_52F.
       BC__32             BC1_52F.
       BC__33             BC1_52F.
       BC__34             BC1_52F.
       BC__35             BC1_52F.
       BC__36             BC1_52F.
       BC__37             BC1_52F.
       BC__38             BC1_52F.
       BC__39             BC1_52F.
       BC__40             BC1_52F.
       BC__41             BC1_52F.
       BC__42             BC1_52F.
       BC__43             BC1_52F.
       BC__44             BC1_52F.
       BC__45             BC1_52F.
       BC__46             BC1_52F.
       BC__47             BC1_52F.
       BC__48             BC1_52F.
       BC__49             BC1_52F.
       BC__50             BC1_52F.
       BC__51             BC1_52F.
       BC__52             BC1_52F.
       wvarstrr           3.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 8 THEN  edad_ac = .M;

   IF  sexo = 9 THEN  sexo = .S;
   IF  edad_ac = 9 THEN  edad_ac = .S;


   ARRAY perdidos1(52)
                   BC__01 BC__02 BC__03 BC__04 BC__05 BC__06 BC__07 BC__08 BC__09 BC__10
                   BC__11 BC__12 BC__13 BC__14 BC__15 BC__16 BC__17 BC__18 BC__19 BC__20
                   BC__21 BC__22 BC__23 BC__24 BC__25 BC__26 BC__27 BC__28 BC__29 BC__30
                   BC__31 BC__32 BC__33 BC__34 BC__35 BC__36 BC__37 BC__38 BC__39 BC__40
                   BC__41 BC__42 BC__43 BC__44 BC__45 BC__46 BC__47 BC__48 BC__49 BC__50
                   BC__51 BC__52;
   DO  i=1 TO 52;
          IF perdidos1{i} = 8   THEN  perdidos1{i} = .M;
          IF perdidos1{i} = 9   THEN  perdidos1{i} = .S;
   END;

   drop i;
RUN;
